@@ -1,5 +1,5 @@
-import pytest
 import mock
+import pytest
 from pullbug.cli import PullBug
 
 
@@ -7,6 +7,7 @@ from pullbug.cli import PullBug
 def test_throw_missing_error(mock_logger):
     with pytest.raises(ValueError):
         PullBug.throw_missing_error('GITHUB_TOKEN')
+
     mock_logger.critical.assert_called_once_with(
         'No GITHUB_TOKEN set. Please correct and try again.'
     )
@@ -15,7 +16,8 @@ def test_throw_missing_error(mock_logger):
 @mock.patch('pullbug.cli.LOGGER')
 def test_run_missing_checks_no_github_or_gitlab(mock_logger):
     with pytest.raises(ValueError):
-        PullBug.run_missing_checks(False, False, False, False)
+        PullBug.run_missing_checks(False, False, False, False, False)
+
     mock_logger.critical.assert_called_once_with(
         'Neither "github" nor "gitlab" flags were passed, one is required. Please correct and try again.'
     )
@@ -26,8 +28,9 @@ def test_run_missing_checks_no_github_or_gitlab(mock_logger):
 @mock.patch('pullbug.github_bug.GithubBug.run')
 @mock.patch('pullbug.cli.LOGGER')
 def test_run_with_github_arg(mock_logger, mock_github, mock_missing_checks):
-    PullBug.run(True, False, False, False, False, 'mock-owner', 'open', 'orgs', 'opened', 'all')
-    mock_missing_checks.assert_called_once_with(True, False, False, False)
+    PullBug.run(True, False, False, False, False, False, 'mock-owner', 'open', 'orgs', 'opened', 'all')
+
+    mock_missing_checks.assert_called_once_with(True, False, False, False, False)
     mock_github.assert_called_once()
     mock_logger.info.assert_called()
 
@@ -37,17 +40,29 @@ def test_run_with_github_arg(mock_logger, mock_github, mock_missing_checks):
 @mock.patch('pullbug.gitlab_bug.GitlabBug.run')
 @mock.patch('pullbug.cli.LOGGER')
 def test_run_with_gitlab_arg(mock_logger, mock_gitlab, mock_missing_checks):
-    PullBug.run(False, True, False, False, False, 'mock-owner', 'open', 'orgs', 'opened', 'all')
-    mock_missing_checks.assert_called_once_with(False, True, False, False)
+    PullBug.run(False, True, False, False, False, False, 'mock-owner', 'open', 'orgs', 'opened', 'all')
+
+    mock_missing_checks.assert_called_once_with(False, True, False, False, False)
     mock_gitlab.assert_called_once()
     mock_logger.info.assert_called()
 
 
+@mock.patch('pullbug.cli.GITHUB_TOKEN', '123')
+@mock.patch('pullbug.cli.LOGGER')
+def test_run_missing_checks_no_discord_webhook_url(mock_logger):
+    message = 'No DISCORD_WEBHOOK_URL set. Please correct and try again.'
+    with pytest.raises(ValueError):
+        PullBug.run_missing_checks(True, False, True, False, False)
+
+    mock_logger.critical.assert_called_once_with(message)
+
+
 @mock.patch('pullbug.cli.LOGGER')
 def test_run_missing_checks_no_github_token(mock_logger):
     message = 'No GITHUB_TOKEN set. Please correct and try again.'
     with pytest.raises(ValueError):
-        PullBug.run_missing_checks(True, False, False, False)
+        PullBug.run_missing_checks(True, False, False, False, False)
+
     mock_logger.critical.assert_called_once_with(message)
 
 
@@ -55,7 +70,8 @@ def test_run_missing_checks_no_github_token(mock_logger):
 def test_run_missing_checks_no_gitlab_api_key(mock_logger):
     message = 'No GITLAB_API_KEY set. Please correct and try again.'
     with pytest.raises(ValueError):
-        PullBug.run_missing_checks(False, True, False, False)
+        PullBug.run_missing_checks(False, True, False, False, False)
+
     mock_logger.critical.assert_called_once_with(message)
 
 
@@ -64,7 +80,8 @@ def test_run_missing_checks_no_gitlab_api_key(mock_logger):
 def test_run_missing_checks_no_slack_bot_token(mock_logger):
     message = 'No SLACK_BOT_TOKEN set. Please correct and try again.'
     with pytest.raises(ValueError):
-        PullBug.run_missing_checks(True, False, True, False)
+        PullBug.run_missing_checks(True, False, False, True, False)
+
     mock_logger.critical.assert_called_once_with(message)
 
 
@@ -74,7 +91,8 @@ def test_run_missing_checks_no_slack_bot_token(mock_logger):
 def test_run_missing_checks_no_slack_channel(mock_logger):
     message = 'No SLACK_CHANNEL set. Please correct and try again.'
     with pytest.raises(ValueError):
-        PullBug.run_missing_checks(True, False, True, False)
+        PullBug.run_missing_checks(True, False, False, True, False)
+
     mock_logger.critical.assert_called_once_with(message)
 
 
@@ -83,7 +101,8 @@ def test_run_missing_checks_no_slack_channel(mock_logger):
 def test_run_missing_checks_no_rocket_chat_url(mock_logger):
     message = 'No ROCKET_CHAT_URL set. Please correct and try again.'
     with pytest.raises(ValueError):
-        PullBug.run_missing_checks(True, False, False, True)
+        PullBug.run_missing_checks(True, False, False, False, True)
+
     mock_logger.critical.assert_called_once_with(message)
 
 
@@ -93,5 +112,6 @@ def test_run_missing_checks_no_rocket_chat_url(mock_logger):
 @mock.patch('pullbug.cli.GITHUB_TOKEN', '123')
 @mock.patch('pullbug.cli.LOGGER')
 def test_run_missing_checks_no_errors(mock_logger):
-    PullBug.run_missing_checks(True, False, False, True)
+    PullBug.run_missing_checks(True, False, False, False, True)
+
     mock_logger.critical.assert_not_called()
